==> ask-sdk-model-1.47.0.tar.gz: ask-sdk-model-1.47.0/ask_sdk_model/services/datastore/v1/__init__.py <==
# coding: utf-8

#
# Copyright 2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the 'License'). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#
from __future__ import absolute_import

from .clear_command import ClearCommand
from .commands_request_error import CommandsRequestError
from .commands_response import CommandsResponse
from .remove_object_command import RemoveObjectCommand
from .commands_request_error_type import CommandsRequestErrorType
from .remove_namespace_command import RemoveNamespaceCommand
from .target import Target
from .commands_dispatch_result import CommandsDispatchResult
from .put_object_command import PutObjectCommand
from .command import Command
from .response_pagination_context import ResponsePaginationContext
from .queued_result_response import QueuedResultResponse
from .commands_request import CommandsRequest
from .user import User
from .queued_result_request_error_type import QueuedResultRequestErrorType
from .dispatch_result_type import DispatchResultType
from .devices import Devices
from .queued_result_request_error import QueuedResultRequestError
from .put_namespace_command import PutNamespaceCommand

==> ask-sdk-model-1.60.0.tar.gz: ask-sdk-model-1.60.0/ask_sdk_model/services/datastore/v1/__init__.py <==
# coding: utf-8

#
# Copyright 2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the 'License'). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#
from __future__ import absolute_import

from .clear_command import ClearCommand
from .commands_request_error import CommandsRequestError
from .commands_response import CommandsResponse
from .remove_object_command import RemoveObjectCommand
from .commands_request_error_type import CommandsRequestErrorType
from .cancel_commands_request_error_type import CancelCommandsRequestErrorType
from .remove_namespace_command import RemoveNamespaceCommand
from .target import Target
from .commands_dispatch_result import CommandsDispatchResult
from .put_object_command import PutObjectCommand
from .command import Command
from .response_pagination_context import ResponsePaginationContext
from .cancel_commands_request_error import CancelCommandsRequestError
from .queued_result_response import QueuedResultResponse
from .commands_request import CommandsRequest
from .user import User
from .queued_result_request_error_type import QueuedResultRequestErrorType
from .dispatch_result_type import DispatchResultType
from .devices import Devices
from .queued_result_request_error import QueuedResultRequestError
from .put_namespace_command import PutNamespaceCommand
